summaryrefslogtreecommitdiffstats
path: root/src/os-plugins
diff options
context:
space:
mode:
authorMichael Janczyk2012-12-07 17:11:52 +0100
committerMichael Janczyk2012-12-07 17:11:52 +0100
commit386ac7aa6bb5f1a75c622488674ffdb42596f4dd (patch)
tree142f273fb03f419fe454a1a798f2384d41897f3a /src/os-plugins
parent- respect blacklisting of modules when autoloading modules in hwautocfg '-b' ... (diff)
downloadcore-386ac7aa6bb5f1a75c622488674ffdb42596f4dd.tar.gz
core-386ac7aa6bb5f1a75c622488674ffdb42596f4dd.tar.xz
core-386ac7aa6bb5f1a75c622488674ffdb42596f4dd.zip
Added missing plugin files for RHEL, Scientific Linux and CentOS Linux.
Removed deprecated SciLin files. postinit.local from the InitRamFS will be executed, if fetching of the tgz file fails.
Diffstat (limited to 'src/os-plugins')
-rw-r--r--src/os-plugins/plugins/desktop/OpenSLX/Distro/Centos.pm31
-rw-r--r--src/os-plugins/plugins/desktop/OpenSLX/Distro/Rhel.pm (renamed from src/os-plugins/plugins/desktop/OpenSLX/Distro/Scilin.pm)6
-rw-r--r--src/os-plugins/plugins/desktop/OpenSLX/Distro/Scientific.pm31
-rw-r--r--src/os-plugins/plugins/infoscreen/OpenSLX/Distro/Centos.pm29
-rw-r--r--src/os-plugins/plugins/infoscreen/OpenSLX/Distro/Rhel.pm (renamed from src/os-plugins/plugins/infoscreen/OpenSLX/Distro/Scilin.pm)9
-rw-r--r--src/os-plugins/plugins/infoscreen/OpenSLX/Distro/Scientific.pm29
-rw-r--r--src/os-plugins/plugins/kiosk/OpenSLX/Distro/Centos.pm29
-rw-r--r--src/os-plugins/plugins/kiosk/OpenSLX/Distro/Rhel.pm (renamed from src/os-plugins/plugins/kiosk/OpenSLX/Distro/Scilin.pm)10
-rw-r--r--src/os-plugins/plugins/kiosk/OpenSLX/Distro/Scientific.pm29
-rw-r--r--src/os-plugins/plugins/profile/OpenSLX/Distro/Centos.pm29
-rw-r--r--src/os-plugins/plugins/profile/OpenSLX/Distro/Rhel.pm (renamed from src/os-plugins/plugins/profile/OpenSLX/Distro/Scilin.pm)9
-rw-r--r--src/os-plugins/plugins/profile/OpenSLX/Distro/Scientific.pm29
-rw-r--r--src/os-plugins/plugins/vmgrid/OpenSLX/OSPlugin/vmgrid.pm2
13 files changed, 249 insertions, 23 deletions
diff --git a/src/os-plugins/plugins/desktop/OpenSLX/Distro/Centos.pm b/src/os-plugins/plugins/desktop/OpenSLX/Distro/Centos.pm
new file mode 100644
index 00000000..8f726037
--- /dev/null
+++ b/src/os-plugins/plugins/desktop/OpenSLX/Distro/Centos.pm
@@ -0,0 +1,31 @@
+# Copyright (c) 2006..2009 - OpenSLX GmbH
+#
+# This program is free software distributed under the GPL version 2.
+# See http://openslx.org/COPYING
+#
+# If you have any feedback please consult http://openslx.org/feedback and
+# send your suggestions, praise, or complaints to feedback@openslx.org
+#
+# General information about OpenSLX can be found at http://openslx.org/
+# -----------------------------------------------------------------------------
+# desktop/OpenSLX/Distro/Centos.pm
+# - provides Centos Linux specific overrides of the Distro API for the
+# desktop plugin.
+# -----------------------------------------------------------------------------
+package desktop::OpenSLX::Distro::Centos;
+
+use strict;
+use warnings;
+
+use base qw(desktop::OpenSLX::Distro::Rhel);
+
+use File::Path;
+
+use OpenSLX::Basics;
+use OpenSLX::Utils;
+
+################################################################################
+### interface methods
+################################################################################
+
+1;
diff --git a/src/os-plugins/plugins/desktop/OpenSLX/Distro/Scientific.pm b/src/os-plugins/plugins/desktop/OpenSLX/Distro/Scientific.pm
new file mode 100644
index 00000000..9f2eedbc
--- /dev/null
+++ b/src/os-plugins/plugins/desktop/OpenSLX/Distro/Scientific.pm
@@ -0,0 +1,31 @@
+# Copyright (c) 2006..2009 - OpenSLX GmbH
+#
+# This program is free software distributed under the GPL version 2.
+# See http://openslx.org/COPYING
+#
+# If you have any feedback please consult http://openslx.org/feedback and
+# send your suggestions, praise, or complaints to feedback@openslx.org
+#
+# General information about OpenSLX can be found at http://openslx.org/
+# -----------------------------------------------------------------------------
+# desktop/OpenSLX/Distro/Scientific.pm
+# - provides Scientific Linux specific overrides of the Distro API for the
+# desktop plugin.
+# -----------------------------------------------------------------------------
+package desktop::OpenSLX::Distro::Scientific;
+
+use strict;
+use warnings;
+
+use base qw(desktop::OpenSLX::Distro::Rhel);
+
+use File::Path;
+
+use OpenSLX::Basics;
+use OpenSLX::Utils;
+
+################################################################################
+### interface methods
+################################################################################
+
+1;
diff --git a/src/os-plugins/plugins/infoscreen/OpenSLX/Distro/Centos.pm b/src/os-plugins/plugins/infoscreen/OpenSLX/Distro/Centos.pm
new file mode 100644
index 00000000..2f0ad7cd
--- /dev/null
+++ b/src/os-plugins/plugins/infoscreen/OpenSLX/Distro/Centos.pm
@@ -0,0 +1,29 @@
+# Copyright (c) 2009 - OpenSLX GmbH
+#
+# This program is free software distributed under the GPL version 2.
+# See http://openslx.org/COPYING
+#
+# If you have any feedback please consult http://openslx.org/feedback and
+# send your suggestions, praise, or complaints to feedback@openslx.org
+#
+# General information about OpenSLX can be found at http://openslx.org/
+# -----------------------------------------------------------------------------
+# infoscreen/OpenSLX/Distro/Centos.pm
+# - provides Centos Linux specific overrides of the Distro API for the
+# infoscreen plugin.
+# -----------------------------------------------------------------------------
+package infoscreen::OpenSLX::Distro::Centos;
+
+use strict;
+use warnings;
+
+use base qw(infoscreen::OpenSLX::Distro::Rhel);
+
+use OpenSLX::Basics;
+use OpenSLX::Utils;
+
+################################################################################
+### interface methods
+################################################################################
+
+1;
diff --git a/src/os-plugins/plugins/infoscreen/OpenSLX/Distro/Scientific.pm b/src/os-plugins/plugins/infoscreen/OpenSLX/Distro/Scientific.pm
new file mode 100644
index 00000000..5f791132
--- /dev/null
+++ b/src/os-plugins/plugins/infoscreen/OpenSLX/Distro/Scientific.pm
@@ -0,0 +1,29 @@
+# Copyright (c) 2009 - OpenSLX GmbH
+#
+# This program is free software distributed under the GPL version 2.
+# See http://openslx.org/COPYING
+#
+# If you have any feedback please consult http://openslx.org/feedback and
+# send your suggestions, praise, or complaints to feedback@openslx.org
+#
+# General information about OpenSLX can be found at http://openslx.org/
+# -----------------------------------------------------------------------------
+# infoscreen/OpenSLX/Distro/Scientific.pm
+# - provides Scientific Linux specific overrides of the Distro API for the
+# infoscreen plugin.
+# -----------------------------------------------------------------------------
+package infoscreen::OpenSLX::Distro::Scientific;
+
+use strict;
+use warnings;
+
+use base qw(infoscreen::OpenSLX::Distro::Rhel);
+
+use OpenSLX::Basics;
+use OpenSLX::Utils;
+
+################################################################################
+### interface methods
+################################################################################
+
+1;
diff --git a/src/os-plugins/plugins/kiosk/OpenSLX/Distro/Centos.pm b/src/os-plugins/plugins/kiosk/OpenSLX/Distro/Centos.pm
new file mode 100644
index 00000000..68877fd7
--- /dev/null
+++ b/src/os-plugins/plugins/kiosk/OpenSLX/Distro/Centos.pm
@@ -0,0 +1,29 @@
+# Copyright (c) 2009 - OpenSLX GmbH
+#
+# This program is free software distributed under the GPL version 2.
+# See http://openslx.org/COPYING
+#
+# If you have any feedback please consult http://openslx.org/feedback and
+# send your suggestions, praise, or complaints to feedback@openslx.org
+#
+# General information about OpenSLX can be found at http://openslx.org/
+# -----------------------------------------------------------------------------
+# kiosk/OpenSLX/Distro/Centos.pm
+# - provides Centos Linux specific overrides of the Distro API for the
+# kiosk plugin.
+# -----------------------------------------------------------------------------
+package kiosk::OpenSLX::Distro::Centos;
+
+use strict;
+use warnings;
+
+use base qw(kiosk::OpenSLX::Distro::Rhel);
+
+use OpenSLX::Basics;
+use OpenSLX::Utils;
+
+################################################################################
+### interface methods
+################################################################################
+
+1;
diff --git a/src/os-plugins/plugins/kiosk/OpenSLX/Distro/Scientific.pm b/src/os-plugins/plugins/kiosk/OpenSLX/Distro/Scientific.pm
new file mode 100644
index 00000000..4e664c76
--- /dev/null
+++ b/src/os-plugins/plugins/kiosk/OpenSLX/Distro/Scientific.pm
@@ -0,0 +1,29 @@
+# Copyright (c) 2009 - OpenSLX GmbH
+#
+# This program is free software distributed under the GPL version 2.
+# See http://openslx.org/COPYING
+#
+# If you have any feedback please consult http://openslx.org/feedback and
+# send your suggestions, praise, or complaints to feedback@openslx.org
+#
+# General information about OpenSLX can be found at http://openslx.org/
+# -----------------------------------------------------------------------------
+# kiosk/OpenSLX/Distro/Scientific.pm
+# - provides Scientific Linux specific overrides of the Distro API for the
+# kiosk plugin.
+# -----------------------------------------------------------------------------
+package kiosk::OpenSLX::Distro::Scientific;
+
+use strict;
+use warnings;
+
+use base qw(kiosk::OpenSLX::Distro::Rhel);
+
+use OpenSLX::Basics;
+use OpenSLX::Utils;
+
+################################################################################
+### interface methods
+################################################################################
+
+1;
diff --git a/src/os-plugins/plugins/profile/OpenSLX/Distro/Centos.pm b/src/os-plugins/plugins/profile/OpenSLX/Distro/Centos.pm
new file mode 100644
index 00000000..99d12703
--- /dev/null
+++ b/src/os-plugins/plugins/profile/OpenSLX/Distro/Centos.pm
@@ -0,0 +1,29 @@
+# Copyright (c) 2009 - OpenSLX GmbH
+#
+# This program is free software distributed under the GPL version 2.
+# See http://openslx.org/COPYING
+#
+# If you have any feedback please consult http://openslx.org/feedback and
+# send your suggestions, praise, or complaints to feedback@openslx.org
+#
+# General information about OpenSLX can be found at http://openslx.org/
+# -----------------------------------------------------------------------------
+# profile/OpenSLX/Distro/Centos.pm
+# - provides Centos Linux specific overrides of the Distro API for the
+# profile plugin.
+# -----------------------------------------------------------------------------
+package profile::OpenSLX::Distro::Centos;
+
+use strict;
+use warnings;
+
+use base qw(profile::OpenSLX::Distro::Rhel);
+
+use OpenSLX::Basics;
+use OpenSLX::Utils;
+
+################################################################################
+### interface methods
+################################################################################
+
+1;
diff --git a/src/os-plugins/plugins/profile/OpenSLX/Distro/Scientific.pm b/src/os-plugins/plugins/profile/OpenSLX/Distro/Scientific.pm
new file mode 100644
index 00000000..e040e3f8
--- /dev/null
+++ b/src/os-plugins/plugins/profile/OpenSLX/Distro/Scientific.pm
@@ -0,0 +1,29 @@
+# Copyright (c) 2009 - OpenSLX GmbH
+#
+# This program is free software distributed under the GPL version 2.
+# See http://openslx.org/COPYING
+#
+# If you have any feedback please consult http://openslx.org/feedback and
+# send your suggestions, praise, or complaints to feedback@openslx.org
+#
+# General information about OpenSLX can be found at http://openslx.org/
+# -----------------------------------------------------------------------------
+# profile/OpenSLX/Distro/Scientific.pm
+# - provides Scientific Linux specific overrides of the Distro API for the
+# profile plugin.
+# -----------------------------------------------------------------------------
+package profile::OpenSLX::Distro::Scientific;
+
+use strict;
+use warnings;
+
+use base qw(profile::OpenSLX::Distro::Rhel);
+
+use OpenSLX::Basics;
+use OpenSLX::Utils;
+
+################################################################################
+### interface methods
+################################################################################
+
+1;
diff --git a/src/os-plugins/plugins/vmgrid/OpenSLX/OSPlugin/vmgrid.pm b/src/os-plugins/plugins/vmgrid/OpenSLX/OSPlugin/vmgrid.pm
index 0965b482..0100d553 100644
--- a/src/os-plugins/plugins/vmgrid/OpenSLX/OSPlugin/vmgrid.pm
+++ b/src/os-plugins/plugins/vmgrid/OpenSLX/OSPlugin/vmgrid.pm
@@ -131,7 +131,7 @@ sub getAttrInfo
comma separated list. first will be started first,
second second, and so on, max. 4 VMs
End-of-Here
- content_descr => 'name of xml file e.g. scilin-5.4-wn(.xml)',
+ content_descr => 'name of xml file e.g. rhel-5-wn(.xml)',
default => undef,
},
'vmgrid::vt' => {
diff --git a/src/os-plugins/plugins/desktop/OpenSLX/Distro/Scilin.pm b/src/os-plugins/plugins/desktop/OpenSLX/Distro/Rhel.pm
index 1dc0482c..9a04afc4 100644
--- a/src/os-plugins/plugins/desktop/OpenSLX/Distro/Scilin.pm
+++ b/src/os-plugins/plugins/desktop/OpenSLX/Distro/Rhel.pm
@@ -8,11 +8,11 @@
#
# General information about OpenSLX can be found at http://openslx.org/
# -----------------------------------------------------------------------------
# desktop/OpenSLX/Distro/Scilin.pm
# - provides Scilin-specific overrides of the Distro API for the desktop
# plugin.
# -----------------------------------------------------------------------------
-package desktop::OpenSLX::Distro::Scilin;
+package desktop::OpenSLX::Distro::Rhel;
use strict;
use warnings;
@@ -8,11 +8,11 @@
# General information about OpenSLX can be found at http://openslx.org/
# -----------------------------------------------------------------------------
-# desktop/OpenSLX/Distro/Scilin.pm
-# - provides Scilin-specific overrides of the Distro API for the desktop
+# desktop/OpenSLX/Distro/Rhel.pm
+# - provides RHEL specific overrides of the Distro API for the desktop
# plugin.
# -----------------------------------------------------------------------------
diff --git a/src/os-plugins/plugins/infoscreen/OpenSLX/Distro/Scilin.pm b/src/os-plugins/plugins/infoscreen/OpenSLX/Distro/Rhel.pm
index e89d6d88..a5988166 100644
--- a/src/os-plugins/plugins/infoscreen/OpenSLX/Distro/Scilin.pm
+++ b/src/os-plugins/plugins/infoscreen/OpenSLX/Distro/Rhel.pm
@@ -8,11 +8,11 @@
#
# General information about OpenSLX can be found at http://openslx.org/
# -----------------------------------------------------------------------------
# infoscreen/OpenSLX/Distro/Scilin.pm
# - provides Scilin-specific overrides of the Distro API for the infoscreen
# plugin.
# -----------------------------------------------------------------------------
-package infoscreen::OpenSLX::Distro::Scilin;
+package infoscreen::OpenSLX::Distro::Rhel;
use strict;
use warnings;
@@ -26,7 +26,4 @@ use OpenSLX::Utils;
### interface methods
################################################################################
-
-
-
1;
@@ -8,11 +8,11 @@
# General information about OpenSLX can be found at http://openslx.org/
# -----------------------------------------------------------------------------
-# infoscreen/OpenSLX/Distro/Scilin.pm
-# - provides Scilin-specific overrides of the Distro API for the infoscreen
+# infoscreen/OpenSLX/Distro/Rhel.pm
+# - provides RHEL specific overrides of the Distro API for the infoscreen
# plugin.
# -----------------------------------------------------------------------------
diff --git a/src/os-plugins/plugins/kiosk/OpenSLX/Distro/Scilin.pm b/src/os-plugins/plugins/kiosk/OpenSLX/Distro/Rhel.pm
index 7423a3b8..6c0f9c9f 100644
--- a/src/os-plugins/plugins/kiosk/OpenSLX/Distro/Scilin.pm
+++ b/src/os-plugins/plugins/kiosk/OpenSLX/Distro/Rhel.pm
@@ -8,11 +8,10 @@
#
# General information about OpenSLX can be found at http://openslx.org/
# -----------------------------------------------------------------------------
# kiosk/OpenSLX/Distro/Scilin.pm
# - provides Scilin-specific overrides of the Distro API for the kiosk
# plugin.
# -----------------------------------------------------------------------------
-package kiosk::OpenSLX::Distro::Scilin;
+package kiosk::OpenSLX::Distro::Rhel;
use strict;
use warnings;
@@ -26,7 +25,4 @@ use OpenSLX::Utils;
### interface methods
################################################################################
-
-
-
1;
@@ -8,11 +8,10 @@
# General information about OpenSLX can be found at http://openslx.org/
# -----------------------------------------------------------------------------
-# kiosk/OpenSLX/Distro/Scilin.pm
-# - provides Scilin-specific overrides of the Distro API for the kiosk
-# plugin.
+# kiosk/OpenSLX/Distro/Rhel.pm
+# - provides RHEL specific overrides of the Distro API for the kiosk plugin.
# -----------------------------------------------------------------------------
diff --git a/src/os-plugins/plugins/profile/OpenSLX/Distro/Scilin.pm b/src/os-plugins/plugins/profile/OpenSLX/Distro/Rhel.pm
index de66f02a..92d599d8 100644
--- a/src/os-plugins/plugins/profile/OpenSLX/Distro/Scilin.pm
+++ b/src/os-plugins/plugins/profile/OpenSLX/Distro/Rhel.pm
@@ -8,11 +8,11 @@
#
# General information about OpenSLX can be found at http://openslx.org/
# -----------------------------------------------------------------------------
# profile/OpenSLX/Distro/Scilin.pm
# - provides Scilin-specific overrides of the Distro API for the profile
# plugin.
# -----------------------------------------------------------------------------
-package profile::OpenSLX::Distro::Scilin;
+package profile::OpenSLX::Distro::Rhel;
use strict;
use warnings;
@@ -26,7 +26,4 @@ use OpenSLX::Utils;
### interface methods
################################################################################
-
-
-
1;
@@ -8,11 +8,11 @@
# General information about OpenSLX can be found at http://openslx.org/
# -----------------------------------------------------------------------------
-# profile/OpenSLX/Distro/Scilin.pm
-# - provides Scilin-specific overrides of the Distro API for the profile
+# profile/OpenSLX/Distro/Rhel.pm
+# - provides RHEL specific overrides of the Distro API for the profile
# plugin.
# -----------------------------------------------------------------------------